=======
Credits
=======

Development Lead
----------------

* Ross A. Beyer <rbeyer@seti.org>

Contributors
------------

* `Jesse Mapel <https://github.com/jessemapel>`_


Emulation of some pysis functions and exceptions based on the pysis
code by William Trevor Olson.
